==> aws-cdk-scala-dlm_3-0.1.4-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"dlm","t":"dlm","d":"","k":"static"},
{"l":"io/burkard/cdk/services/dlm.html","n":"io.burkard.cdk.services.dlm","t":"package io.burkard.cdk.services.dlm","d":"io/burkard/cdk/services/dlm","k":"package"},
{"l":"io/burkard/cdk/services/dlm/ActionProperty$.html","n":"ActionProperty","t":"object ActionProperty","d":"io/burkard/cdk/services/dlm/ActionProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/ActionProperty$.html","n":"apply","t":"def apply(name: Option[String], crossRegionCopy: Option[List[_]]): ActionProperty","d":"io/burkard/cdk/services/dlm/ActionProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/CfnLifecyclePolicy$.html","n":"CfnLifecyclePolicy","t":"object CfnLifecyclePolicy","d":"io/burkard/cdk/services/dlm/CfnLifecyclePolicy$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/CfnLifecyclePolicy$.html","n":"apply","t":"def apply(internalResourceId: String, state: Option[String], executionRoleArn: Option[String], policyDetails: Option[PolicyDetailsProperty], description: Option[String], tags: Option[List[_ <: CfnTag]])(implicit stackCtx: Stack): CfnLifecyclePolicy","d":"io/burkard/cdk/services/dlm/CfnLifecyclePolicy$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/CfnLifecyclePolicyProps$.html","n":"CfnLifecyclePolicyProps","t":"object CfnLifecyclePolicyProps","d":"io/burkard/cdk/services/dlm/CfnLifecyclePolicyProps$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/CfnLifecyclePolicyProps$.html","n":"apply","t":"def apply(state: Option[String], executionRoleArn: Option[String], policyDetails: Option[PolicyDetailsProperty], description: Option[String], tags: Option[List[_ <: CfnTag]]): CfnLifecyclePolicyProps","d":"io/burkard/cdk/services/dlm/CfnLifecyclePolicyProps$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/CreateRuleProperty$.html","n":"CreateRuleProperty","t":"object CreateRuleProperty","d":"io/burkard/cdk/services/dlm/CreateRuleProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/CreateRuleProperty$.html","n":"apply","t":"def apply(interval: Option[Number], times: Option[List[String]], cronExpression: Option[String], intervalUnit: Option[String], location: Option[String]): CreateRuleProperty","d":"io/burkard/cdk/services/dlm/CreateRuleProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/CrossRegionCopyActionProperty$.html","n":"CrossRegionCopyActionProperty","t":"object CrossRegionCopyActionProperty","d":"io/burkard/cdk/services/dlm/CrossRegionCopyActionProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/CrossRegionCopyActionProperty$.html","n":"apply","t":"def apply(encryptionConfiguration: Option[EncryptionConfigurationProperty], retainRule: Option[CrossRegionCopyRetainRuleProperty], target: Option[String]): CrossRegionCopyActionProperty","d":"io/burkard/cdk/services/dlm/CrossRegionCopyActionProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/CrossRegionCopyDeprecateRuleProperty$.html","n":"CrossRegionCopyDeprecateRuleProperty","t":"object CrossRegionCopyDeprecateRuleProperty","d":"io/burkard/cdk/services/dlm/CrossRegionCopyDeprecateRuleProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/CrossRegionCopyDeprecateRuleProperty$.html","n":"apply","t":"def apply(intervalUnit: Option[String], interval: Option[Number]): CrossRegionCopyDeprecateRuleProperty","d":"io/burkard/cdk/services/dlm/CrossRegionCopyDeprecateRuleProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/CrossRegionCopyRetainRuleProperty$.html","n":"CrossRegionCopyRetainRuleProperty","t":"object CrossRegionCopyRetainRuleProperty","d":"io/burkard/cdk/services/dlm/CrossRegionCopyRetainRuleProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/CrossRegionCopyRetainRuleProperty$.html","n":"apply","t":"def apply(intervalUnit: Option[String], interval: Option[Number]): CrossRegionCopyRetainRuleProperty","d":"io/burkard/cdk/services/dlm/CrossRegionCopyRetainRuleProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/CrossRegionCopyRuleProperty$.html","n":"CrossRegionCopyRuleProperty","t":"object CrossRegionCopyRuleProperty","d":"io/burkard/cdk/services/dlm/CrossRegionCopyRuleProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/CrossRegionCopyRuleProperty$.html","n":"apply","t":"def apply(copyTags: Option[Boolean], encrypted: Option[Boolean], deprecateRule: Option[CrossRegionCopyDeprecateRuleProperty], targetRegion: Option[String], target: Option[String], cmkArn: Option[String], retainRule: Option[CrossRegionCopyRetainRuleProperty]): CrossRegionCopyRuleProperty","d":"io/burkard/cdk/services/dlm/CrossRegionCopyRuleProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/DeprecateRuleProperty$.html","n":"DeprecateRuleProperty","t":"object DeprecateRuleProperty","d":"io/burkard/cdk/services/dlm/DeprecateRuleProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/DeprecateRuleProperty$.html","n":"apply","t":"def apply(count: Option[Number], intervalUnit: Option[String], interval: Option[Number]): DeprecateRuleProperty","d":"io/burkard/cdk/services/dlm/DeprecateRuleProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/EncryptionConfigurationProperty$.html","n":"EncryptionConfigurationProperty","t":"object EncryptionConfigurationProperty","d":"io/burkard/cdk/services/dlm/EncryptionConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/EncryptionConfigurationProperty$.html","n":"apply","t":"def apply(cmkArn: Option[String], encrypted: Option[Boolean]): EncryptionConfigurationProperty","d":"io/burkard/cdk/services/dlm/EncryptionConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/EventParametersProperty$.html","n":"EventParametersProperty","t":"object EventParametersProperty","d":"io/burkard/cdk/services/dlm/EventParametersProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/EventParametersProperty$.html","n":"apply","t":"def apply(descriptionRegex: Option[String], eventType: Option[String], snapshotOwner: Option[List[String]]): EventParametersProperty","d":"io/burkard/cdk/services/dlm/EventParametersProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/EventSourceProperty$.html","n":"EventSourceProperty","t":"object EventSourceProperty","d":"io/burkard/cdk/services/dlm/EventSourceProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/EventSourceProperty$.html","n":"apply","t":"def apply(`type`: Option[String], parameters: Option[EventParametersProperty]): EventSourceProperty","d":"io/burkard/cdk/services/dlm/EventSourceProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/FastRestoreRuleProperty$.html","n":"FastRestoreRuleProperty","t":"object FastRestoreRuleProperty","d":"io/burkard/cdk/services/dlm/FastRestoreRuleProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/FastRestoreRuleProperty$.html","n":"apply","t":"def apply(count: Option[Number], intervalUnit: Option[String], interval: Option[Number], availabilityZones: Option[List[String]]): FastRestoreRuleProperty","d":"io/burkard/cdk/services/dlm/FastRestoreRuleProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/ParametersProperty$.html","n":"ParametersProperty","t":"object ParametersProperty","d":"io/burkard/cdk/services/dlm/ParametersProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/ParametersProperty$.html","n":"apply","t":"def apply(noReboot: Option[Boolean], excludeBootVolume: Option[Boolean]): ParametersProperty","d":"io/burkard/cdk/services/dlm/ParametersProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/PolicyDetailsProperty$.html","n":"PolicyDetailsProperty","t":"object PolicyDetailsProperty","d":"io/burkard/cdk/services/dlm/PolicyDetailsProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/PolicyDetailsProperty$.html","n":"apply","t":"def apply(targetTags: Option[List[_]], schedules: Option[List[_]], policyType: Option[String], actions: Option[List[_]], parameters: Option[ParametersProperty], resourceLocations: Option[List[String]], eventSource: Option[EventSourceProperty], resourceTypes: Option[List[String]]): PolicyDetailsProperty","d":"io/burkard/cdk/services/dlm/PolicyDetailsProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/RetainRuleProperty$.html","n":"RetainRuleProperty","t":"object RetainRuleProperty","d":"io/burkard/cdk/services/dlm/RetainRuleProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/RetainRuleProperty$.html","n":"apply","t":"def apply(count: Option[Number], intervalUnit: Option[String], interval: Option[Number]): RetainRuleProperty","d":"io/burkard/cdk/services/dlm/RetainRuleProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/ScheduleProperty$.html","n":"ScheduleProperty","t":"object ScheduleProperty","d":"io/burkard/cdk/services/dlm/ScheduleProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/ScheduleProperty$.html","n":"apply","t":"def apply(retainRule: Option[RetainRuleProperty], fastRestoreRule: Option[FastRestoreRuleProperty], deprecateRule: Option[DeprecateRuleProperty], shareRules: Option[List[_]], variableTags: Option[List[_]], createRule: Option[CreateRuleProperty], name: Option[String], copyTags: Option[Boolean], crossRegionCopyRules: Option[List[_]], tagsToAdd: Option[List[_]]): ScheduleProperty","d":"io/burkard/cdk/services/dlm/ScheduleProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/ShareRuleProperty$.html","n":"ShareRuleProperty","t":"object ShareRuleProperty","d":"io/burkard/cdk/services/dlm/ShareRuleProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/ShareRuleProperty$.html","n":"apply","t":"def apply(unshareInterval: Option[Number], unshareIntervalUnit: Option[String], targetAccounts: Option[List[String]]): ShareRuleProperty","d":"io/burkard/cdk/services/dlm/ShareRuleProperty$","k":"def"},
{"l":"docs/index.html","n":"dlm","t":"dlm","d":"","k":"static"}];

==> aws-cdk-scala-dlm_3-0.1.5-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"dlm","t":"dlm","d":"","k":"static"},
{"l":"io/burkard/cdk/services/dlm.html","n":"io.burkard.cdk.services.dlm","t":"package io.burkard.cdk.services.dlm","d":"io/burkard/cdk/services/dlm","k":"package"},
{"l":"io/burkard/cdk/services/dlm/ActionProperty$.html","n":"ActionProperty","t":"object ActionProperty","d":"io/burkard/cdk/services/dlm/ActionProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/ActionProperty$.html","n":"apply","t":"def apply(name: String, crossRegionCopy: List[_]): ActionProperty","d":"io/burkard/cdk/services/dlm/ActionProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/CfnLifecyclePolicy$.html","n":"CfnLifecyclePolicy","t":"object CfnLifecyclePolicy","d":"io/burkard/cdk/services/dlm/CfnLifecyclePolicy$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/CfnLifecyclePolicy$.html","n":"apply","t":"def apply(internalResourceId: String, state: Option[String], executionRoleArn: Option[String], policyDetails: Option[PolicyDetailsProperty], description: Option[String], tags: Option[List[_ <: CfnTag]])(implicit stackCtx: Stack): CfnLifecyclePolicy","d":"io/burkard/cdk/services/dlm/CfnLifecyclePolicy$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/CfnLifecyclePolicyProps$.html","n":"CfnLifecyclePolicyProps","t":"object CfnLifecyclePolicyProps","d":"io/burkard/cdk/services/dlm/CfnLifecyclePolicyProps$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/CfnLifecyclePolicyProps$.html","n":"apply","t":"def apply(state: Option[String], executionRoleArn: Option[String], policyDetails: Option[PolicyDetailsProperty], description: Option[String], tags: Option[List[_ <: CfnTag]]): CfnLifecyclePolicyProps","d":"io/burkard/cdk/services/dlm/CfnLifecyclePolicyProps$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/CreateRuleProperty$.html","n":"CreateRuleProperty","t":"object CreateRuleProperty","d":"io/burkard/cdk/services/dlm/CreateRuleProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/CreateRuleProperty$.html","n":"apply","t":"def apply(interval: Option[Number], times: Option[List[String]], cronExpression: Option[String], intervalUnit: Option[String], location: Option[String]): CreateRuleProperty","d":"io/burkard/cdk/services/dlm/CreateRuleProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/CrossRegionCopyActionProperty$.html","n":"CrossRegionCopyActionProperty","t":"object CrossRegionCopyActionProperty","d":"io/burkard/cdk/services/dlm/CrossRegionCopyActionProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/CrossRegionCopyActionProperty$.html","n":"apply","t":"def apply(encryptionConfiguration: EncryptionConfigurationProperty, target: String, retainRule: Option[CrossRegionCopyRetainRuleProperty]): CrossRegionCopyActionProperty","d":"io/burkard/cdk/services/dlm/CrossRegionCopyActionProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/CrossRegionCopyDeprecateRuleProperty$.html","n":"CrossRegionCopyDeprecateRuleProperty","t":"object CrossRegionCopyDeprecateRuleProperty","d":"io/burkard/cdk/services/dlm/CrossRegionCopyDeprecateRuleProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/CrossRegionCopyDeprecateRuleProperty$.html","n":"apply","t":"def apply(intervalUnit: String, interval: Number): CrossRegionCopyDeprecateRuleProperty","d":"io/burkard/cdk/services/dlm/CrossRegionCopyDeprecateRuleProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/CrossRegionCopyRetainRuleProperty$.html","n":"CrossRegionCopyRetainRuleProperty","t":"object CrossRegionCopyRetainRuleProperty","d":"io/burkard/cdk/services/dlm/CrossRegionCopyRetainRuleProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/CrossRegionCopyRetainRuleProperty$.html","n":"apply","t":"def apply(intervalUnit: String, interval: Number): CrossRegionCopyRetainRuleProperty","d":"io/burkard/cdk/services/dlm/CrossRegionCopyRetainRuleProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/CrossRegionCopyRuleProperty$.html","n":"CrossRegionCopyRuleProperty","t":"object CrossRegionCopyRuleProperty","d":"io/burkard/cdk/services/dlm/CrossRegionCopyRuleProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/CrossRegionCopyRuleProperty$.html","n":"apply","t":"def apply(encrypted: Boolean, copyTags: Option[Boolean], deprecateRule: Option[CrossRegionCopyDeprecateRuleProperty], targetRegion: Option[String], target: Option[String], cmkArn: Option[String], retainRule: Option[CrossRegionCopyRetainRuleProperty]): CrossRegionCopyRuleProperty","d":"io/burkard/cdk/services/dlm/CrossRegionCopyRuleProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/DeprecateRuleProperty$.html","n":"DeprecateRuleProperty","t":"object DeprecateRuleProperty","d":"io/burkard/cdk/services/dlm/DeprecateRuleProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/DeprecateRuleProperty$.html","n":"apply","t":"def apply(count: Option[Number], intervalUnit: Option[String], interval: Option[Number]): DeprecateRuleProperty","d":"io/burkard/cdk/services/dlm/DeprecateRuleProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/EncryptionConfigurationProperty$.html","n":"EncryptionConfigurationProperty","t":"object EncryptionConfigurationProperty","d":"io/burkard/cdk/services/dlm/EncryptionConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/EncryptionConfigurationProperty$.html","n":"apply","t":"def apply(encrypted: Boolean, cmkArn: Option[String]): EncryptionConfigurationProperty","d":"io/burkard/cdk/services/dlm/EncryptionConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/EventParametersProperty$.html","n":"EventParametersProperty","t":"object EventParametersProperty","d":"io/burkard/cdk/services/dlm/EventParametersProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/EventParametersProperty$.html","n":"apply","t":"def apply(eventType: String, snapshotOwner: List[String], descriptionRegex: Option[String]): EventParametersProperty","d":"io/burkard/cdk/services/dlm/EventParametersProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/EventSourceProperty$.html","n":"EventSourceProperty","t":"object EventSourceProperty","d":"io/burkard/cdk/services/dlm/EventSourceProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/EventSourceProperty$.html","n":"apply","t":"def apply(`type`: String, parameters: Option[EventParametersProperty]): EventSourceProperty","d":"io/burkard/cdk/services/dlm/EventSourceProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/FastRestoreRuleProperty$.html","n":"FastRestoreRuleProperty","t":"object FastRestoreRuleProperty","d":"io/burkard/cdk/services/dlm/FastRestoreRuleProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/FastRestoreRuleProperty$.html","n":"apply","t":"def apply(count: Option[Number], intervalUnit: Option[String], interval: Option[Number], availabilityZones: Option[List[String]]): FastRestoreRuleProperty","d":"io/burkard/cdk/services/dlm/FastRestoreRuleProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/ParametersProperty$.html","n":"ParametersProperty","t":"object ParametersProperty","d":"io/burkard/cdk/services/dlm/ParametersProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/ParametersProperty$.html","n":"apply","t":"def apply(noReboot: Option[Boolean], excludeBootVolume: Option[Boolean]): ParametersProperty","d":"io/burkard/cdk/services/dlm/ParametersProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/PolicyDetailsProperty$.html","n":"PolicyDetailsProperty","t":"object PolicyDetailsProperty","d":"io/burkard/cdk/services/dlm/PolicyDetailsProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/PolicyDetailsProperty$.html","n":"apply","t":"def apply(targetTags: Option[List[_]], schedules: Option[List[_]], policyType: Option[String], actions: Option[List[_]], parameters: Option[ParametersProperty], resourceLocations: Option[List[String]], eventSource: Option[EventSourceProperty], resourceTypes: Option[List[String]]): PolicyDetailsProperty","d":"io/burkard/cdk/services/dlm/PolicyDetailsProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/RetainRuleProperty$.html","n":"RetainRuleProperty","t":"object RetainRuleProperty","d":"io/burkard/cdk/services/dlm/RetainRuleProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/RetainRuleProperty$.html","n":"apply","t":"def apply(count: Option[Number], intervalUnit: Option[String], interval: Option[Number]): RetainRuleProperty","d":"io/burkard/cdk/services/dlm/RetainRuleProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/ScheduleProperty$.html","n":"ScheduleProperty","t":"object ScheduleProperty","d":"io/burkard/cdk/services/dlm/ScheduleProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/ScheduleProperty$.html","n":"apply","t":"def apply(retainRule: Option[RetainRuleProperty], fastRestoreRule: Option[FastRestoreRuleProperty], deprecateRule: Option[DeprecateRuleProperty], shareRules: Option[List[_]], variableTags: Option[List[_]], createRule: Option[CreateRuleProperty], name: Option[String], copyTags: Option[Boolean], crossRegionCopyRules: Option[List[_]], tagsToAdd: Option[List[_]]): ScheduleProperty","d":"io/burkard/cdk/services/dlm/ScheduleProperty$","k":"def"},
{"l":"io/burkard/cdk/services/dlm/ShareRuleProperty$.html","n":"ShareRuleProperty","t":"object ShareRuleProperty","d":"io/burkard/cdk/services/dlm/ShareRuleProperty$","k":"object"},
{"l":"io/burkard/cdk/services/dlm/ShareRuleProperty$.html","n":"apply","t":"def apply(unshareInterval: Option[Number], unshareIntervalUnit: Option[String], targetAccounts: Option[List[String]]): ShareRuleProperty","d":"io/burkard/cdk/services/dlm/ShareRuleProperty$","k":"def"},
{"l":"docs/index.html","n":"dlm","t":"dlm","d":"","k":"static"}];
